from setuptools import find_packages, setup
setup(
    name='TurkeyLastQuakeAlert',
    packages=find_packages(),
    version='0.1.0',
    description='Kandilli and AFAD API.',
    author='userdotcs',
    license='MIT',
)